
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include "e-mail-engine-enumtypes.h"
/* enumerations from "e-mail-engine-enums.h" */
#include "e-mail-engine-enums.h"
GType
e_mail_local_folder_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_MAIL_LOCAL_FOLDER_INBOX,
			  "E_MAIL_LOCAL_FOLDER_INBOX",
			  "local-folder-inbox" },
			{ E_MAIL_LOCAL_FOLDER_DRAFTS,
			  "E_MAIL_LOCAL_FOLDER_DRAFTS",
			  "local-folder-drafts" },
			{ E_MAIL_LOCAL_FOLDER_OUTBOX,
			  "E_MAIL_LOCAL_FOLDER_OUTBOX",
			  "local-folder-outbox" },
			{ E_MAIL_LOCAL_FOLDER_SENT,
			  "E_MAIL_LOCAL_FOLDER_SENT",
			  "local-folder-sent" },
			{ E_MAIL_LOCAL_FOLDER_TEMPLATES,
			  "E_MAIL_LOCAL_FOLDER_TEMPLATES",
			  "local-folder-templates" },
			{ E_MAIL_LOCAL_FOLDER_LOCAL_INBOX,
			  "E_MAIL_LOCAL_FOLDER_LOCAL_INBOX",
			  "local-folder-local-inbox" },
			{ E_MAIL_NUM_LOCAL_FOLDERS,
			  "E_MAIL_NUM_LOCAL_FOLDERS",
			  "num-local-folders" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EMailLocalFolder"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_mail_recipient_certificate_lookup_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_MAIL_RECIPIENT_CERTIFICATE_LOOKUP_OFF,
			  "E_MAIL_RECIPIENT_CERTIFICATE_LOOKUP_OFF",
			  "off" },
			{ E_MAIL_RECIPIENT_CERTIFICATE_LOOKUP_AUTOCOMPLETED,
			  "E_MAIL_RECIPIENT_CERTIFICATE_LOOKUP_AUTOCOMPLETED",
			  "autocompleted" },
			{ E_MAIL_RECIPIENT_CERTIFICATE_LOOKUP_BOOKS,
			  "E_MAIL_RECIPIENT_CERTIFICATE_LOOKUP_BOOKS",
			  "books" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EMailRecipientCertificateLookup"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}

/* Generated data ends here */

